#!/bin/bash
# Script used to prepare for eZ Publish/Platfrom archives
#
# Pre-requirement for LTS (EE) archives (not affecting ezpublish-community):
#     Because of authentication for packages, composer auth extension must be installed using:
#     ```composer global require "bitexpert/composer-authstore-plugin=0.2.*"```
#     If auth.json is placed in COMPOSER_HOME, it needs to be for same user as the one executing script.



# TEMP: Force icu 1.1 for Redhat 6.x installs to not crash if 1.2 is picked
composer require "symfony/icu 1.1.*" --no-update

# Install all composer deps non-interactivly (yml parameters will be set to default values)
composer install -n --prefer-dist --no-dev

# TEMP: Cleanup after icu 1.1 so installations will get suitable version on update
git checkout composer.json

# Replace install instructions for archive instructions
mv -f INSTALL_ARCHIVE.md INSTALL.md

# Rename .gitignore to make it optional
mv .gitignore .gitignore.dist

# Remove cache (wrong paths), logs (generated by composer call above) & zeta tests (too big)
rm -Rf ezpublish/cache/*/* ezpublish/logs/* vendor/zetacomponents/*/tests

# Remove git folders (also for kernel and legacy as composer sometimes clones instead of downloading)
rm -Rf .git ezpublish_legacy/.git vendor/ezsystems/ezpublish-kernel/.git


echo << EOF
Ready to archive the result

Assuming current folder is build/ezpublish5 this can be accomplished in the following way:
    cd ../..
    tar czf dist/ezpublish5-\$version-ee-gpl-full.tar.gz --directory=build ezpublish5
EOF
